@@ -2,6 +2,8 @@
 #this repository contains the full copyright notices and license terms.
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.pyson import Not, Eval, Bool, Or
+from trytond.backend import TableHandler
+from trytond.transaction import Transaction
 
 
 class Category(ModelSQL, ModelView):
@@ -24,9 +26,9 @@ class Category(ModelSQL, ModelView):
             'invisible': Not(Bool(Eval('company'))),
         }))
     customer_taxes = fields.Many2Many('product.category-customer-account.tax',
-            'product', 'tax', 'Customer Taxes', domain=[('parent', '=', False)])
+            'category', 'tax', 'Customer Taxes', domain=[('parent', '=', False)])
     supplier_taxes = fields.Many2Many('product.category-supplier-account.tax',
-            'product', 'tax', 'Supplier Taxes', domain=[('parent', '=', False)])
+            'category', 'tax', 'Supplier Taxes', domain=[('parent', '=', False)])
 
 Category()
 
@@ -36,11 +38,21 @@ class CategoryCustomerTax(ModelSQL):
     _name = 'product.category-customer-account.tax'
     _table = 'product_category_customer_taxes_rel'
     _description = __doc__
-    product = fields.Many2One('product.category', 'Category',
+    category = fields.Many2One('product.category', 'Category',
             ondelete='CASCADE', select=1, required=True)
     tax = fields.Many2One('account.tax', 'Tax', ondelete='RESTRICT',
             required=True)
 
+    def init(self, module_name):
+        cursor = Transaction().cursor
+        # Migration from 1.6 product renamed into category
+        table = TableHandler(cursor, self)
+        if table.column_exist('product'):
+            table.index_action('product', action='remove')
+            table.drop_fk('product')
+            table.column_rename('product', 'category')
+        super(CategoryCustomerTax, self).init(module_name)
+
 CategoryCustomerTax()
 
 
@@ -49,11 +61,21 @@ class CategorySupplierTax(ModelSQL):
     _name = 'product.category-supplier-account.tax'
     _table = 'product_category_supplier_taxes_rel'
     _description = __doc__
-    product = fields.Many2One('product.category', 'Category',
+    category = fields.Many2One('product.category', 'Category',
             ondelete='CASCADE', select=1, required=True)
     tax = fields.Many2One('account.tax', 'Tax', ondelete='RESTRICT',
             required=True)
 
+    def init(self, module_name):
+        cursor = Transaction().cursor
+        # Migration from 1.6 product renamed into category
+        table = TableHandler(cursor, self)
+        if table.column_exist('product'):
+            table.index_action('product', action='remove')
+            table.drop_fk('product')
+            table.column_rename('product', 'category')
+        super(CategorySupplierTax, self).init(module_name)
+
 CategorySupplierTax()
 
 
@@ -113,28 +135,28 @@ class Template(ModelSQL, ModelView):
                     '%s (%d)',
             })
 
-    def default_taxes_category(self, cursor, user, context=None):
+    def default_taxes_category(self):
         return False
 
-    def get_account(self, cursor, user, ids, name, context=None):
+    def get_account(self, ids, name):
         account_obj = self.pool.get('account.account')
         res = {}
         name = name[:-5]
-        for product in self.browse(cursor, user, ids, context=context):
+        for product in self.browse(ids):
             if product[name]:
                 res[product.id] = product[name].id
             else:
                 if product.category[name]:
                     res[product.id] = product.category[name].id
                 else:
-                    self.raise_user_error(cursor, 'missing_account',
-                            (product.name, product.id), context=context)
+                    self.raise_user_error('missing_account',
+                            (product.name, product.id))
         return res
 
-    def get_taxes(self, cursor, user, ids, name, context=None):
+    def get_taxes(self, ids, name):
         res = {}
         name = name[:-5]
-        for product in self.browse(cursor, user, ids, context=context):
+        for product in self.browse(ids):
             if product.taxes_category:
                 res[product.id] = [x.id for x in product.category[name]]
             else:
